import _plotly_utils.basevalidators


class ShowlowerhalfValidator(_plotly_utils.basevalidators.BooleanValidator):
    def __init__(self, plotly_name="showlowerhalf", parent_name="splom", **kwargs):
        super(ShowlowerhalfValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "calc"),
            role=kwargs.pop("role", "info"),
            **kwargs
        )
